@@ -7,6 +7,7 @@ import (
 
 	"github.com/projectdiscovery/goflags"
 	"github.com/projectdiscovery/katana/pkg/output"
+	fileutil "github.com/projectdiscovery/utils/file"
 )
 
 // OnResultCallback (output.Result)
@@ -15,6 +16,8 @@ type OnResultCallback func(output.Result)
 type Options struct {
 	// URLs contains a list of URLs for crawling
 	URLs goflags.StringSlice
+	// Resume the scan from the state stored in the resume config file
+	Resume string
 	// Scope contains a list of regexes for in-scope URLS
 	Scope goflags.StringSlice
 	// OutOfScope contains a list of regexes for out-scope URLS
@@ -141,6 +144,8 @@ type Options struct {
 	Debug bool
 	// TlsImpersonate enables experimental tls ClientHello randomization for standard crawler
 	TlsImpersonate bool
+	//DisableRedirects disables the following of redirects
+	DisableRedirects bool
 }
 
 func (options *Options) ParseCustomHeaders() map[string]string {
@@ -154,15 +159,30 @@ func (options *Options) ParseCustomHeaders() map[string]string {
 }
 
 func (options *Options) ParseHeadlessOptionalArguments() map[string]string {
-	optionalArguments := make(map[string]string)
+	var (
+		lastKey           string
+		optionalArguments = make(map[string]string)
+	)
 	for _, v := range options.HeadlessOptionalArguments {
+		if v == "" {
+			continue
+		}
 		if argParts := strings.SplitN(v, "=", 2); len(argParts) >= 2 {
 			key := strings.TrimSpace(argParts[0])
 			value := strings.TrimSpace(argParts[1])
 			if key != "" && value != "" {
 				optionalArguments[key] = value
+				lastKey = key
 			}
+		} else if !strings.HasPrefix(v, "--") {
+			optionalArguments[lastKey] += "," + v
+		} else {
+			optionalArguments[v] = ""
 		}
 	}
 	return optionalArguments
 }
+
+func (options *Options) ShouldResume() bool {
+	return options.Resume != "" && fileutil.FileExists(options.Resume)
+}
